labeltools.label_vertical_moments_in_expr_with_counterpoint_intervals
=====================================================================

.. autofunction:: abjad.tools.labeltools.label_vertical_moments_in_expr_with_counterpoint_intervals.label_vertical_moments_in_expr_with_counterpoint_intervals
   :noindex:
